@@ -5,8 +5,10 @@ function _aws_cdk_aws_refactorspaces_CfnApplicationProps(p) {
     try {
         if (!visitedObjects.has(p.apiGatewayProxy))
             _aws_cdk_aws_refactorspaces_CfnApplication_ApiGatewayProxyInputProperty(p.apiGatewayProxy);
-        if (!visitedObjects.has(p.tags))
-            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
     }
     finally {
         visitedObjects.delete(p);
@@ -21,8 +23,10 @@ function _aws_cdk_aws_refactorspaces_CfnEnvironmentProps(p) {
         return;
     visitedObjects.add(p);
     try {
-        if (!visitedObjects.has(p.tags))
-            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
     }
     finally {
         visitedObjects.delete(p);
@@ -35,8 +39,10 @@ function _aws_cdk_aws_refactorspaces_CfnRouteProps(p) {
         return;
     visitedObjects.add(p);
     try {
-        if (!visitedObjects.has(p.tags))
-            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
     }
     finally {
         visitedObjects.delete(p);
@@ -53,8 +59,10 @@ function _aws_cdk_aws_refactorspaces_CfnServiceProps(p) {
         return;
     visitedObjects.add(p);
     try {
-        if (!visitedObjects.has(p.tags))
-            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
     }
     finally {
         visitedObjects.delete(p);
